# Related Projects

Below is a list of repos and tools that are built using or can be used alongside **PyDM**.

| Project | Description |
|---|---|
| **[pydm-converter-tool](https://github.com/slaclab/pydm-converter-tool)** | Tool for converting legacy control system displays (eg. EDM) into PyDM. |
| **[trace](https://github.com/slaclab/trace)** | Flexible + modern PyDM-based application for plotting live data (Channel Access or PV Access), and historical data from the EPICS Archive Appliance. |
| **[timechart](https://github.com/slaclab/timechart)** | PyDM-based graphing application for control systems: intended to be the modern, feature-by-feature matching alternative to the Motif EPICS Strip Tool application. |
| **[Rogue](https://github.com/slaclab/rogue)** | Python based hardware abstraction & data acquisition system using PyDM for its GUI. |
| **[Typhos](https://github.com/pcdshub/typhos)** | Automatic-yet-customizable GUI generation for Ophyd devices, built using PyDM. |
| **[edmbutton](https://github.com/slaclab/edmbutton)** | PyDM widget for launching EDM displays. |
---
